==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/admin/actions/maintenance_ranking_upload.php <==
<?php
// $Revision: 1.1.2.2 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

// check token ticket
require_once( '../class/base/gtickets.php' );
$ticket_area = 'xoonips_admin_maintenance_ranking';
if ( ! $xoopsGTicket->check( true, $ticket_area, false ) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors() );
  exit();
}

// load xoonips abstract layer for xnpRecalcRanking()
include_once '../include/lib.php';
require_once '../include/create_session.php';
include_once '../include/unzip.php';
xnp_load_init_create_session();
$xnpsid = $_SESSION['XNPSID'];

// TODO: use object handler
$names = array( 'viewed_item', 'downloaded_item', 'contributing_user', 'searched_keyword', 'active_group', 'new_item', 'new_group' );
$columns = array( 'item_id, count', 'item_id, count', 'item_id, uid, timestamp', 'keyword, count', 'gid, count', 'item_id, timestamp', 'gid, timestamp', );
$configs = array( 'ranking_sum_last_update', 'ranking_sum_start' );
	
/** write csv lines to table */
function load_ranking_file( $lines, $name, $columns ){
  global $xoopsDB;
  $table = $xoopsDB->prefix( 'xoonips_ranking_sum_'.$name );
  $xoopsDB->query( "delete from $table" );
  foreach ( $lines as $line ){
    if ( $line === "" )
      continue;
    $ar = explode( ',', $line );
    $Row = array();
    foreach ( $ar as $val ){
      if ( is_numeric( $val ) ) {
        $Row[] = floor($val);
      } else {
        $Row[] = "'" . addslashes(urldecode( $val )) . "'";
      }
    }
    $sql = "insert into $table ( $columns ) values ( ".implode( ',', $Row )." )";
    if ( false == $xoopsDB->query( $sql ) ){
      echo "error while loading. \n";
    }
  }
}

if ( ! isset( $_FILES['ranking_upload_file'] ) ||
  $_FILES['ranking_upload_file']['name'] == '' ||
  $_FILES['ranking_upload_file']['size'] == 0 ||
  ! is_uploaded_file($_FILES['ranking_upload_file']['tmp_name']) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_ILLACCESS );
  exit();
}

// extract sum 
$uploadfile = $_FILES['ranking_upload_file']['tmp_name'];
$hdl = fopen( $uploadfile, 'rb' );
if( !$hdl ) exit( "can't open file ".$uploadfile );
fseek( $hdl, 0, SEEK_SET );
$entries = unzip_all_entries( $hdl );

foreach( $entries as $entry ){
  $data = unzip_read_data( $entry );
  $lines = explode( "\n", $data );
  unset( $data );
  switch ( $entry['filename'] ){
  case $names[0]: load_ranking_file( $lines, $names[0], $columns[0] ); break;
  case $names[1]: load_ranking_file( $lines, $names[1], $columns[1] ); break;
  case $names[2]: load_ranking_file( $lines, $names[2], $columns[2] ); break;
  case $names[3]: load_ranking_file( $lines, $names[3], $columns[3] ); break;
  case $names[4]: load_ranking_file( $lines, $names[4], $columns[4] ); break;
  case $names[5]: load_ranking_file( $lines, $names[5], $columns[5] ); break;
  case $names[6]: load_ranking_file( $lines, $names[6], $columns[6] ); break;
  case 'config': 
    foreach ( $lines as $line ){
      if ( $line === "" )
        continue;
      list( $key, $val ) = explode( ',', $line );
      if ( in_array( $key, $configs ) )
        xnp_set_config_value( $key, $val );
    }
    break;
  }
}
fclose( $hdl );

// recalc cache
xnpRecalcRanking( false );

redirect_header( $xoonips_admin['mypage_url'], 1, _AM_XOONIPS_MSG_DBUPDATED );

?>

==> xoonips-3.41.tar.gz: xoonips-3.41/xoonips/admin/actions/maintenance_ranking_upload.php <==
<?php
// $Revision: 1.1.4.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
  exit();
}

// check token ticket
require_once( '../class/base/gtickets.php' );
$ticket_area = 'xoonips_admin_maintenance_ranking';
if ( ! $xoopsGTicket->check( true, $ticket_area, false ) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, $xoopsGTicket->getErrors() );
  exit();
}

$keys = array(
  'ranking_upload_file' => array(
    'd',
    true,
    true,
  ),
);
$vals = xoonips_admin_get_requests( 'files', $keys );
// uploaded file check
$uploaded_file = $vals['ranking_upload_file'];
if ( $uploaded_file['name'] == '' || $uploaded_file['size'] == 0 ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_ILLACCESS );
  exit();
}

// extract sum
$file_path = $uploaded_file['tmp_name'];
$admin_ranking_handler =& xoonips_gethandler( 'xoonips', 'admin_ranking' );
if ( ! $admin_ranking_handler->load_sum_file( $file_path ) ) {
  redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MAINTENANCE_RANKING_LOCKED );
  exit();
}

redirect_header( $xoonips_admin['mypage_url'], 1, _AM_XOONIPS_MSG_DBUPDATED );

?>
